@@ -35,7 +35,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdint.h>
-#include <stdbool.h>
 #include <string.h>
 #include <time.h>
 #include <limits.h>
@@ -47,7 +46,6 @@ main (int argc, char *argv[])
   char otp[YUBIKEY_OTP_SIZE];
   char *aeskey, *yk_internalname, *yk_counter, *yk_low, *yk_high, *yk_use;
   yubikey_token_st tok;
-  int i;
 
   /* Initiate pseudo-random generator */
   srand (time (NULL));
@@ -139,11 +137,14 @@ main (int argc, char *argv[])
 
   yubikey_generate ((void *) &tok, key, otp);
 
-  for (i = 0; i < 32; i++)
-    {
+  {
+    size_t i;
+
+    for (i = 0; i < 32; i++)
       printf ("%c", otp[i]);
-    }
-  printf ("\n");
+
+    printf ("\n");
+  }
 
   return EXIT_SUCCESS;
 }
